#
# spec file for package python-inline-snapshot
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-inline-snapshot%{psuffix}
Version:        0.19.3
Release:        2.1
Summary:        Create and update inline snapshots in your Python code
License:        MIT
URL:            https://github.com/15r10nk/inline-snapshot/
Source:         https://files.pythonhosted.org/packages/source/i/inline-snapshot/inline_snapshot-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module black >= 23.3.0}
BuildRequires:  %{python_module click >= 8.1.4}
BuildRequires:  %{python_module dirty-equals >= 0.7.0}
BuildRequires:  %{python_module hypothesis >= 6.75.5}
BuildRequires:  %{python_module inline-snapshot = %{version}}
BuildRequires:  %{python_module mypy >= 1.2.0}
BuildRequires:  %{python_module pydantic}
BuildRequires:  %{python_module pyright >= 1.1.359}
BuildRequires:  %{python_module pytest-freezer >= 0.4.8}
BuildRequires:  %{python_module pytest-mock >= 3.14.0}
BuildRequires:  %{python_module pytest-subtests >= 0.11.0}
BuildRequires:  %{python_module pytest-xdist >= 3.6.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module time-machine >= 2.10.0}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-asttokens >= 2.0.5
Requires:       python-executing >= 2.0.0
Requires:       python-rich >= 13.7.1
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli >= 2.0.0
%endif
Suggests:       python-black >= 23.3
Suggests:       python-click >= 8.1.4
Suggests:       python-dirty-equals >= 0.9
BuildArch:      noarch
%python_subpackages

%description
Create and update inline snapshots in your Python code.

%prep
%autosetup -p1 -n inline_snapshot-%{version}

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
#NOTE: disable test_typing because the underlying pyright module uses
# nodeenv, which required https connection to nodejs.org. This is not
# possible in OBS.
%if %{with test}
%pytest -v -k 'not (test_typing or test_format_command_fail)'
%endif

%if %{without test}
%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/inline_snapshot
%{python_sitelib}/inline_snapshot-%{version}.dist-info
%endif

%changelog
* Wed Jan 29 2025 Steve Kowalik <steven.kowalik@suse.com>
- Inject multibuild to break a build cycle.
* Thu Jan 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.19.3:
  * Added
    + added the optional inline-snapshot[dirty-equals] dependency to depend
    on the dirty-equals version which works in combination with
    inline-snapshot.
    + You can now specify which tool you want to use to format your code by
    setting a format-command in your configuration.
    + Support for a new storage-dir configuration option, to tell
    inline-snapshot where to store data files such as external snapshots.
    + attrs can now contain unmanaged values
    + inline_snapshot.extra.warns to captures warnings and compares them
    against expected warnings.
    + snapshots inside snapshots are now supported.
    + runtime values can now be part of snapshots.
    + f-strings can now also be used within snapshots, but are currently not
    fixed by inline-snapshot.
  * Changed
    + BREAKING-CHANGE you have to install inline-snapshot[black] now if you
    want to format your code like in the previous versions. This option is
    not required if you use a format-command.
    + dirty-equals expressions are now treated like runtime values or
    snapshots within snapshots and are not modified by inline-snapshot.
  * Fixed
    + raise no assertion for positional arguments inside constructor methods.
    + fixed a crash when you changed the snapshot to use a custom constructoro
    method for dataclass/pydantic models.
    + snapshots with pydantic models can now be compared multiple times
    + Load default config values even if [tool.inline-snapshot] is missing.
    + use '.model_fields' on pydantic model class and not instance.
    + pydantic v1 is supported again.
    + Code generation for sets is now deterministic.
    + solved a bug caused by a variable inside a snapshot
    + inline-snapshot checks now if the given command line flags
    (--inline-snapshot=...) are valid
    + do not crash when handling raw f-strings (rf"",RF"",...)
    + Don't crash for snapshots like snapshot(f"")
    + skip formatting if black returns an error
* Wed Nov 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.14.0
  * Removed the "Programming Language :: Python :: Implementation :: PyPy"
    classifier which was incorrect, because inline-snapshot can not fix
    snapshots on pypy. inline-snapshot now enforces --inline-snapshot=disable
    when used with an implementation other than cpython, which allows
    it to be used in packages that want to support pypy.
  * Command line shortcuts can be defined to simplify your workflows.
  - -review and --fix are defined by default. See the documentation
    for details.
  * --inline-snapshot=create/fix/trim/update will no longer show reports
    for other categories. You can use --inline-snapshot=create,report
    if you want to use the old behaviour.
- from version to 0.13.4
  * Use tomli instead of toml
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.13.3:
  * removed non-optional dirty-equals dependency
  * star-expressions in list or dicts where never valid and cause
    a warning now.
  * A snapshot which contains an dirty-equals expression can now
    be compared multiple times.
  * Use tomllib instead of PyPI toml on Python 3.11 and later
  * added extra.prints
  * 3.13 support
  * strings with one line-break at the end become no multiline
    strings
* Thu Sep  5 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Fri Aug 16 2024 Guang Yee <gyee@suse.com>
- version 0.12.1
  * add license to project metadata and some other fixes in pyproject.toml (#104)
